# Table of Contents

- [importing-resources-to-fact-sheets](<./importing-resources-to-fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Importing Resources to Fact Sheets](<./Importing-Resources-to-Fact-Sheets.md>)
  - [Overview](<./Importing-Resources-to-Fact-Sheets/Overview.md>)
  - [Prerequisites](<./Importing-Resources-to-Fact-Sheets/Prerequisites.md>)
  - [Step 1: Prepare Data](<./Importing-Resources-to-Fact-Sheets/Step-1-Prepare-Data.md>)
  - [Step 2: Convert a CSV File into LDIF Format](<./Importing-Resources-to-Fact-Sheets/Step-2-Convert-a-CSV-File-into-LDIF-Format.md>)
  - [Step 3: Create an Inbound Data Processor](<./Importing-Resources-to-Fact-Sheets/Step-3-Create-an-Inbound-Data-Processor.md>)
  - [Step 4: Complete a Processor Run to Import Data](<./Importing-Resources-to-Fact-Sheets/Step-4-Complete-a-Processor-Run-to-Import-Data.md>)
  - [Summary](<./Importing-Resources-to-Fact-Sheets/Summary.md>)
  - [Was this page helpful?](<./Importing-Resources-to-Fact-Sheets/Was-this-page-helpful.md>)
